==> dune-pdelab_2.6~20180302.orig.tar.xz: dune-pdelab-2.6~20180302.orig/LICENSE.md <==
Licensing Information
=====================

Copyright holders
-----------------

| Year       | Name                       |
|------------|----------------------------|
| 2009--2016 | Peter Bastian              |
| 2009--2017 | Markus Blatt               |
| 2016       | Lukas Böger                |
| 2013--2016 | Andreas Buhr               |
| 2014--2017 | Ansgar Burchardt           |
| 2011       | Martin Drohmann            |
| 2009--2017 | Christian Engwer           |
| 2009--2017 | Jorrit Fahlke              |
| 2016       | Carsten Gräser             |
| 2015--2016 | Felix Gruber               |
| 2012--2017 | Christoph Grüninger        |
| 2009--2012 | Felix Heimann              |
| 2014--2017 | René Heß                   |
| 2013--2014 | Pavel Hron                 |
| 2014--2017 | Dominic Kempf              |
| 2010--2011 | Ole Klein                  |
| 2016       | Tobias Leibner             |
| 2009--2010 | Sven Marnach               |
| 2015       | René Milk                  |
| 2010--2017 | Steffen Müthing            |
| 2010--2014 | Rebecca Neumann            |
| 2011--2015 | Adrian Ngo                 |
| 2013--2016 | Andreas Nüßing             |
| 2014--2017 | Marian Piatkowski          |
| 2012--2013 | Jurgis Pods                |
| 2016       | Anne Reinarz               |
| 2011       | Hanna Remmel               |
| 2012       | Human Rezaijafari          |
| 2016       | Lukas Riedel               |
| 2014--2016 | Oliver Sander              |
| 2015       | Linus Seelinger            |
| 2016       | Liesel Schumacher          |
| 2012       | Nicolas Schwenck           |
| 2013       | Bård Skaflestad            |
| 2012       | Christian Waluga           |
| 2013--2015 | Sebastian Westerheide      |
| 2012       | Matthias Wohlmuth          |

License
-------

The PDELab library, headers and test programs are copyrighted free software. You
can use, modify and/or redistribute it under the terms of either one of the two
following licenses:

* The GNU Lesser General Public License as published by the Free Software
  Foundation, either Version 3 of the license or (at your option) any later
  version. You can find a copy of the GNU Lesser General Public License, Version
  3, in the files [GPL-3][1] and [LGPL-3][2] or at http://www.gnu.org/licenses/lgpl-3.0.

* Version 2 of the GNU General Public License as published by the Free Software
  Foundation, with the following special exception for linking and compiling
  against the PDELab library, the so-called "runtime exception":

>   As a special exception, you may use the PDELab source files as part of a
>   software library or application without restriction.  Specifically, if other
>   files instantiate templates or use macros or inline functions from one or
>   more of the PDELab source files, or you compile one or more of the PDELab
>   source files and link them with other files to produce an executable, this
>   does not by itself cause the resulting executable to be covered by the GNU
>   General Public License.  This exception does not however invalidate any
>   other reasons why the executable file might be covered by the GNU General
>   Public License.

  This license is intended to be similar to the GNU Lesser General Public
  License, Version 2, which by itself isn't suitable for a template library. You
  can find a copy of the GNU General Public License, Version 2, in the file
  [GPL-2][3] or at http://www.gnu.org/licenses/gpl-2.0.


Links
-----

[1]: GPL-3
[2]: LGPL-3
[3]: GPL-2

==> dune-pdelab_2.7~20200605.orig.tar.xz: dune-pdelab-2.7~20200605.orig/LICENSE.md <==
Licensing Information
=====================

Copyright holders
-----------------

| Year       | Name                       |
|------------|----------------------------|
| 2009--2016 | Peter Bastian              |
| 2009--2017 | Markus Blatt               |
| 2016       | Lukas Böger                |
| 2013--2016 | Andreas Buhr               |
| 2014--2017 | Ansgar Burchardt           |
| 2017       | Tim Dodwell                |
| 2011       | Martin Drohmann            |
| 2009--2018 | Christian Engwer           |
| 2009--2018 | Jorrit Fahlke              |
| 2016--2018 | Carsten Gräser             |
| 2015--2016 | Felix Gruber               |
| 2012--2017 | Christoph Grüninger        |
| 2009--2012 | Felix Heimann              |
| 2014--2018 | René Heß                   |
| 2013--2014 | Pavel Hron                 |
| 2014--2018 | Dominic Kempf              |
| 2010--2011 | Ole Klein                  |
| 2016       | Tobias Leibner             |
| 2009--2010 | Sven Marnach               |
| 2015       | René Milk                  |
| 2010--2018 | Steffen Müthing            |
| 2010--2014 | Rebecca Neumann            |
| 2011--2015 | Adrian Ngo                 |
| 2013--2018 | Andreas Nüßing             |
| 2014--2017 | Marian Piatkowski          |
| 2012--2013 | Jurgis Pods                |
| 2016       | Anne Reinarz               |
| 2011       | Hanna Remmel               |
| 2012       | Human Rezaijafari          |
| 2016       | Lukas Riedel               |
| 2014--2018 | Oliver Sander              |
| 2015       | Linus Seelinger            |
| 2017       | Felix Schindler            |
| 2018       | Sophie Schrader            |
| 2016       | Liesel Schumacher          |
| 2012       | Nicolas Schwenck           |
| 2013       | Bård Skaflestad            |
| 2018       | Arne Strehlow              |
| 2012       | Christian Waluga           |
| 2013--2015 | Sebastian Westerheide      |
| 2012       | Matthias Wohlmuth          |

License
-------

The PDELab library, headers and test programs are copyrighted free software. You
can use, modify and/or redistribute it under the terms of either one of the two
following licenses:

* The GNU Lesser General Public License as published by the Free Software
  Foundation, either Version 3 of the license or (at your option) any later
  version. You can find a copy of the GNU Lesser General Public License, Version
  3, in the files [GPL-3][1] and [LGPL-3][2] or at http://www.gnu.org/licenses/lgpl-3.0.

* Version 2 of the GNU General Public License as published by the Free Software
  Foundation, with the following special exception for linking and compiling
  against the PDELab library, the so-called "runtime exception":

>   As a special exception, you may use the PDELab source files as part of a
>   software library or application without restriction.  Specifically, if other
>   files instantiate templates or use macros or inline functions from one or
>   more of the PDELab source files, or you compile one or more of the PDELab
>   source files and link them with other files to produce an executable, this
>   does not by itself cause the resulting executable to be covered by the GNU
>   General Public License.  This exception does not however invalidate any
>   other reasons why the executable file might be covered by the GNU General
>   Public License.

  This license is intended to be similar to the GNU Lesser General Public
  License, Version 2, which by itself isn't suitable for a template library. You
  can find a copy of the GNU General Public License, Version 2, in the file
  [GPL-2][3] or at http://www.gnu.org/licenses/gpl-2.0.


Links
-----

[1]: GPL-3
[2]: LGPL-3
[3]: GPL-2
